pub struct ComponentHandoff {
pub start_offset_ns: u64,
pub from: ComponentKind,
pub to: ComponentKind,
pub kind: HandoffKind,
pub duration_ns: u64,
pub wait_duration_ns: u64,
pub bytes: Option<u64>,
pub records: Option<u64>,
}Expand description
One ordered handoff between components actually used by a job.
Fields
start_offset_ns: u64Offset from job start where the boundary was observed.
from: ComponentKindCalling component.
to: ComponentKindReceiving component.
kind: HandoffKindFinite handoff class.
duration_ns: u64Handoff wall duration, in nanoseconds.
wait_duration_ns: u64Explicit wait within the handoff.
bytes: Option<u64>Exact bytes, when known.
records: Option<u64>Exact records, when known.