JobStage

Struct JobStage 

pub struct JobStage {
    pub stage: Stage,
    pub component: ComponentKind,
    pub component_role: ComponentRole,
    pub start_offset_ns: u64,
    pub duration_ns: u64,
    pub wait_duration_ns: u64,
    pub wait_reason: Option<WaitReason>,
    pub attempt: u32,
    pub bytes: Option<u64>,
    pub resumed_bytes: Option<u64>,
    pub records: Option<u64>,
    pub outcome: Outcome,
}
One non-overlapping active interval in a local workspace job.

Fields

stage: Stage

Finite stage class.

component: ComponentKind

Component that actually ran.

component_role: ComponentRole

Finite role played by that component.

start_offset_ns: u64

Offset from job start, in nanoseconds.

duration_ns: u64

Wall duration, in nanoseconds.

wait_duration_ns: u64

Time within the interval spent waiting.

wait_reason: Option<WaitReason>

Finite reason when wait duration is nonzero.

attempt: u32

One-based attempt number.

bytes: Option<u64>

Exact byte count, when the operation already knows it.

resumed_bytes: Option<u64>

Bytes already present before this attempt, when the operation knows it.

records: Option<u64>

Exact record count, when the operation already knows it.

outcome: Outcome

Normalized stage outcome.